Repository for Hilltop Python tools
=============================================================

This git repository contains the Hilltop Python tools and associated documentation.

.. Documentation
.. --------------
.. The primary documentation for the package can be found `here <http://pdsql.readthedocs.io>`_.

Installation
------------
pdsql can be installed via pip or conda::

  pip install hilltop-py

or::

  conda install -c mullenkamp hilltop-py

The core dependencies are Pandas and pywin32.

To do
-----
- More documentation
- Unit tests
